Настройка синтезатора речи
Пред. | Глава 3. Настройка | След.

## Настройка синтезатора речи

Синтез речи может использоваться в скриптах для анонсирования каких-то событий, и может быть доступен пользователям через джаббер-бота в развлекательных целях. Работает это так: вы загружаете в медиатеку файл формата OGG/Vorbis (с расширением `.ogg`), затем ardj преобразует текст в речь, записывает в этот файл и ставит его в очередь проигрывания.

Единственным свободным синтезатором речи, прилично говорящим по-русски, является festival. Установить его в системе Debian (Ubuntu) можно такой командой:

    sudo apt-get install festival festvox-ru

После этого загрузите в медиатеку любой файл формата OGG/Vorbis и определите его идентификатор — это делается командой news или find:

    > find экстренное
    Found only these tracks:
    «Экстренное сообщение» by Микроша — #4656 ⚖1.96 ♺323 @special

Укажите найденный идентификатор ("4656" в примере) в конфигурационном файле (обычно `/etc/ardj.yaml`):

    festival_track_id: 4656

После этого перезапустите jabber-бота командой restart, чтобы изменения вступили в силу.

Теперь можно отправить джаббер-боту команду speak с текстом, который ему следует произнести. Результат будет записан в файл, соответствующий указанной дорожке. Выглядит это так:

    > speak привет, меня зовут микроша. гамбургеры заворачивать теперь буду я
    OK, please wait until the current song finishes playing.

Запрошенная фраза прозвучит по окончании проигрываемой композиции. Убедиться, что она встала в очередь, можно командой queue:

    > queue
    Current queue:
    «Экстренное сообщение» by Микроша — #4656 ⚖2.21 ♺325 @special

Пред. | Наверх | След.
Глава 3. Настройка | Начало | Взаимодействие с Last.fm